# rover 

Tool for the robust retrieval of seismic (and other) data from a data center such as the [EarthScope](https://www.earthscope.org/data).  For this tool to work the data center must offer both a [fdsnws-availability](https://service.iris.edu/fdsnws/availability/1/) service and an [fdsnws-dataselect](http://service.iris.edu/fdsnws/dataselect/1/) service.

For more installation instructions and quick start see the [User Guide](https://earthscope.github.io/rover/).
